@@ -16,21 +16,19 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
-#include "config-audiocd.h"
+#include <config-audiocd.h>
 
 #include "encoderlame.h"
 #include "audiocd_lame_encoder.h"
+#include "audiocd_kio_debug.h"
 
-#include <kdebug.h>
-#include <qgroupbox.h>
-#include <qstringlist.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <qapplication.h>
-#include <qfileinfo.h>
-#include <ktemporaryfile.h>
-#include <kstandarddirs.h>
-// #include "collectingprocess.h"
+#include <QDir>
+#include <QFileInfo>
+#include <QStandardPaths>
+#include <QStringList>
+#include <QTemporaryFile>
+
+Q_LOGGING_CATEGORY(AUDIOCD_KIO_LOG, "kf5.kio.audiocd")
 
 extern "C"
 {
@@ -51,7 +49,7 @@ public:
 	QStringList genreList;
 	uint lastSize;
 	KProcess *currentEncodeProcess;
-	KTemporaryFile *tempFile;
+	QTemporaryFile *tempFile;
 };
 
 EncoderLame::EncoderLame(KIO::SlaveBase *slave) : QObject(), AudioCDEncoder(slave) {
@@ -68,7 +66,6 @@ EncoderLame::~EncoderLame(){
 
 QWidget* EncoderLame::getConfigureWidget(KConfigSkeleton** manager) const {
   (*manager) = Settings::self();
-  KGlobal::locale()->insertCatalog( QLatin1String( "audiocd_encoder_lame" ));
   EncoderLameConfig *config = new EncoderLameConfig();
   config->cbr_settings->hide();
   return config;
@@ -76,7 +73,7 @@ QWidget* EncoderLame::getConfigureWidget(KConfigSkeleton** manager) const {
 
 bool EncoderLame::init(){
 	// Determine if lame is installed on the system or not.
-	if ( KStandardDirs::findExe( "lame" ).isEmpty() )
+	if ( QStandardPaths::findExecutable( QStringLiteral( "lame" )).isEmpty() )
 		return false;
 
 	// Ask lame for the list of genres it knows; otherwise it barfs when doing
@@ -101,7 +98,7 @@ bool EncoderLame::init(){
 		genre = genre.mid( i );
 
 	}
-	//kDebug(7117) << "Available genres:" << d->genreList;
+	//qCDebug(AUDIOCD_KIO_LOG) << "Available genres:" << d->genreList;
 
 	return true;
 }
@@ -231,8 +228,7 @@ unsigned long EncoderLame::size(long time_secs) const {
 long EncoderLame::readInit(long /*size*/){
 	// Create KProcess
 	d->currentEncodeProcess	= new KProcess();
-	d->tempFile = new KTemporaryFile();
-	d->tempFile->setSuffix(".mp3");
+	d->tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/kaudiocd_XXXXXX") + QLatin1String(".mp3"));
 	d->tempFile->open();
 	d->lastErrorMessage.clear();
 	d->processHasExited = false;
@@ -247,18 +243,18 @@ long EncoderLame::readInit(long /*size*/){
 	// Read in stdin, output to the temp file
 	*d->currentEncodeProcess << "-" << d->tempFile->fileName().toLatin1();
 
-	//kDebug(7117) << d->currentEncodeProcess->args();
+	//qCDebug(AUDIOCD_KIO_LOG) << d->currentEncodeProcess->args();
 
 
-	connect(d->currentEncodeProcess, SIGNAL(readyReadStandardOutput()),
-                         this, SLOT(receivedStdout()));
-	connect(d->currentEncodeProcess, SIGNAL(readyReadStandardError()),
-                         this, SLOT(receivedStderr()));
-// 	connect(d->currentEncodeProcess, SIGNAL(bytesWritten()),
-//                          this, SLOT(wroteStdin()));
+	connect(d->currentEncodeProcess, &KProcess::readyReadStandardOutput,
+                         this, &EncoderLame::receivedStdout);
+	connect(d->currentEncodeProcess, &KProcess::readyReadStandardError,
+                         this, &EncoderLame::receivedStderr);
+// 	connect(d->currentEncodeProcess, &KProcess::bytesWritten,
+//                          this, &EncoderLame::wroteStdin);
 
-	connect(d->currentEncodeProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
-                         this, SLOT(processExited(int,QProcess::ExitStatus)));
+	connect(d->currentEncodeProcess, QOverload<int, QProcess::ExitStatus>::of(&KProcess::finished),
+                         this, &EncoderLame::processExited);
 
 	// Launch!
 	d->currentEncodeProcess->setOutputChannelMode(KProcess::SeparateChannels);
@@ -267,13 +263,13 @@ long EncoderLame::readInit(long /*size*/){
 }
 
 void EncoderLame::processExited ( int exitCode, QProcess::ExitStatus /*status*/ ){
-	kDebug(7117) << "Lame Encoding process exited with: " << exitCode;
+	qCDebug(AUDIOCD_KIO_LOG) << "Lame Encoding process exited with: " << exitCode;
 	d->processHasExited = true;
 }
 
 void EncoderLame::receivedStderr(){
 	QByteArray error = d->currentEncodeProcess->readAllStandardError();
-	kDebug(7117) << "Lame stderr: " << error;
+	qCDebug(AUDIOCD_KIO_LOG) << "Lame stderr: " << error;
 	if ( !d->lastErrorMessage.isEmpty() )
 		d->lastErrorMessage += '\t';
 	d->lastErrorMessage += QString::fromLocal8Bit( error );
@@ -281,14 +277,14 @@ void EncoderLame::receivedStderr(){
 
 void EncoderLame::receivedStdout(){
 	QString output = QString::fromLocal8Bit(d->currentEncodeProcess->readAllStandardOutput());
-	kDebug(7117) << "Lame stdout: " << output;
+	qCDebug(AUDIOCD_KIO_LOG) << "Lame stdout: " << output;
 }
 
 // void EncoderLame::wroteStdin(){
 // 	d->waitingForWrite = false;
 // }
 
-long EncoderLame::read(int16_t *buf, int frames){
+long EncoderLame::read(qint16 *buf, int frames){
 	if(!d->currentEncodeProcess)
 		return 0;
         if (d->processHasExited)
@@ -369,4 +365,3 @@ QString EncoderLame::lastErrorMessage() const
 	return d->lastErrorMessage;
 }
 
-#include "encoderlame.moc"
